# Saki

![](https://www.beardsleyzoo.org/uploads/1/2/4/2/124214186/245_orig.jpg)

## Desciption

Saki is an alternative of the cat and nano command line tools.


## Install 

### Windows
    1. Go to cmd or powershell and run "pip install windows-curses"
    2. Run "pip install saki"

### Mac/Linux
    1. Run "pip install saki" or "pip3 install saki" if the former doesn't work

## Links

Github - https://github.com/Luke-Pitstick/saki

PyPi - https://pypi.org/project/saki/


